==> teamapps-client-0.9.9.zip: tsd/modules/tool-container/toolbar/UiToolbarButtonGroup.d.ts <==
import { UiToolbarButtonGroupConfig } from "../../../generated/UiToolbarButtonGroupConfig";
import { TeamAppsUiContext } from "../../TeamAppsUiContext";
import { UiToolbarButtonConfig } from "../../../generated/UiToolbarButtonConfig";
import { UiComponent } from "../../UiComponent";
import { ButtonVisibilities, UiToolbar } from "./UiToolbar";
import { UiDropDownButtonClickInfoConfig } from "../../../generated/UiDropDownButtonClickInfoConfig";
import { TeamAppsEvent } from "../../util/TeamAppsEvent";
export declare class UiToolbarButtonGroup {
    private toolbar;
    private context;
    readonly onButtonClicked: TeamAppsEvent<{
        buttonId: string;
        dropDownButtonClickInfo: UiDropDownButtonClickInfoConfig;
    }>;
    readonly onDropDownItemClicked: TeamAppsEvent<{
        buttonId: string;
        groupId: string;
        itemId: number;
    }>;
    private config;
    private visible;
    private $buttonGroupWrapper;
    private $buttonGroup;
    private buttons;
    private $separator;
    private buttonsShiftedToOverflowDropDown;
    constructor(buttonGroupConfig: UiToolbarButtonGroupConfig, toolbar: UiToolbar, context: TeamAppsUiContext);
    getId(): string;
    private readonly toolbarId;
    readonly position: UiToolbarButtonGroupPosition;
    private createButton;
    setDropDownComponent(buttonId: string, component: UiComponent): void;
    setButtonVisible(buttonId: string, visible: boolean): void;
    addButton(buttonConfig: UiToolbarButtonConfig, neighborButtonId: string, beforeNeighbor: boolean): void;
    removeButton(buttonId: string): void;
    setVisible(visible: boolean): void;
    isVisible(): boolean;
    private updateVisibility;
    calculateButtonVisibilities(availableWidth: number): ButtonVisibilities;
    getMainDomElement(): JQuery;
    getButtonConfigs(): UiToolbarButtonConfig[];
    setButtonHasDropDown(buttonId: string, hasDropDown: boolean): void;
    getConfig(): UiToolbarButtonGroupConfig;
}

==> teamapps-client-0.9.12.zip: tsd/modules/tool-container/toolbar/UiToolbarButtonGroup.d.ts <==
import { UiToolbarButtonGroupConfig } from "../../../generated/UiToolbarButtonGroupConfig";
import { TeamAppsUiContext } from "../../TeamAppsUiContext";
import { UiToolbarButtonConfig } from "../../../generated/UiToolbarButtonConfig";
import { UiComponent } from "../../UiComponent";
import { ButtonVisibilities, UiToolbar } from "./UiToolbar";
import { UiDropDownButtonClickInfoConfig } from "../../../generated/UiDropDownButtonClickInfoConfig";
import { TeamAppsEvent } from "../../util/TeamAppsEvent";
export declare class UiToolbarButtonGroup {
    private toolbar;
    private context;
    readonly onButtonClicked: TeamAppsEvent<{
        buttonId: string;
        dropDownButtonClickInfo: UiDropDownButtonClickInfoConfig;
    }>;
    readonly onDropDownItemClicked: TeamAppsEvent<{
        buttonId: string;
        groupId: string;
        itemId: number;
    }>;
    private config;
    private visible;
    private $buttonGroupWrapper;
    private $buttonGroup;
    private buttons;
    private $separator;
    private buttonsShiftedToOverflowDropDown;
    constructor(buttonGroupConfig: UiToolbarButtonGroupConfig, toolbar: UiToolbar, context: TeamAppsUiContext);
    getId(): string;
    private readonly toolbarId;
    readonly position: import("../../../generated/UiToolbarButtonGroupPosition").UiToolbarButtonGroupPosition;
    private createButton;
    setDropDownComponent(buttonId: string, component: UiComponent): void;
    setButtonVisible(buttonId: string, visible: boolean): void;
    addButton(buttonConfig: UiToolbarButtonConfig, neighborButtonId: string, beforeNeighbor: boolean): void;
    removeButton(buttonId: string): void;
    setVisible(visible: boolean): void;
    isVisible(): boolean;
    private updateVisibility;
    calculateButtonVisibilities(availableWidth: number): ButtonVisibilities;
    getMainDomElement(): JQuery;
    getButtonConfigs(): UiToolbarButtonConfig[];
    setButtonHasDropDown(buttonId: string, hasDropDown: boolean): void;
    getConfig(): UiToolbarButtonGroupConfig;
}
